from flask import Blueprint

status = Blueprint('status', __name__, url_prefix='/status')


@status.route('/')
def get_status():
    """ Check if the API is running.
    ---
    responses:
      200:
        description: The API is running.
        content:
          application/json:
            schema:
              $ref: '#/definitions/ApiStatus'
    definitions:
      ApiStatus:
        type: object
        properties:
          status:
            type: string
            description: The API is running
            enum:
              - active
    """
    return {
        'status': 'active'
    }



import os.path

from flask import Blueprint, current_app, abort, send_from_directory

from orka_vector_api import db
from orka_vector_api.exceptions.orka import OrkaException
from orka_vector_api.helper import get_job_id_by_dataid

data = Blueprint('data', __name__, url_prefix='/data')


@data.route('/<uuid:data_id>', methods=['GET'])
def get_data(data_id):
    """Get a single geopackage.
    Get the geopackage with given uuid as filename.
    ---
    parameters:
      - name: data_id
        description: The id of the geopackage to download. The id is provided via the corresponding job.
        in: path
        type: string
        format: uuid
        required: true
    responses:
      200:
        description: The geopackage file.
    produces:
      - application/geopackage+sqlite3
    """
    data_id_str = str(data_id)
    gpkg_path = current_app.config['ORKA_GPKG_PATH']
    filename = data_id_str + '.gpkg'

    conn = db.pool.getconn()
    try:
        # only return a file if it is related to an existing job
        job_id = get_job_id_by_dataid(data_id_str, conn, current_app)
        if job_id is None:
            raise OrkaException('Corresponding job not found.')
        current_app.logger.debug(f'Provided download for {filename} of job {job_id}.')
        response = send_from_directory(os.path.abspath(gpkg_path), filename, mimetype='application/geopackage+sqlite3')
    except OrkaException as e:
        current_app.logger.info(f'Could not provide download for {filename}. No corresponding job found.')
        response = '', 404
    except Exception as e:
        current_app.logger.info(f'Error downloading gpkg. {e}')
        response = '', 404
    finally:
        db.pool.putconn(conn)

    return response


@data.route('/styles', methods=['GET'])
def get_styles_zip():
    """Get the style files, symbols, etc.
    Get all style files as a single .zip file.
    ---
    responses:
      200:
        description: The .zip file containing all styles, etc.
    produces:
      - application/zip
    """
    style_path = current_app.config['ORKA_STYLE_PATH']
    file_name = current_app.config['ORKA_STYLE_FILE']

    current_app.logger.debug(f'Provided download for style file {file_name}.')
    return send_from_directory(os.path.abspath(style_path), file_name, mimetype='application/zip')



from enum import Enum


class Status(Enum):
    INIT = 'INIT'
    RUNNING = 'RUNNING'
    CREATED = 'CREATED'
    ERROR = 'ERROR'
    TIMEOUT = 'TIMEOUT'
    BBOX_TOO_BIG = 'BBOX_TOO_BIG'
    BBOX_INVALID = 'BBOX_INVALID'
    NO_THREADS_AVAILABLE = 'NO_THREADS_AVAILABLE'



import json
import uuid
from flask import Blueprint, request, abort, current_app

from orka_vector_api import db
from orka_vector_api.enums import Status
from orka_vector_api.exceptions.orka import OrkaException
from orka_vector_api.helper import create_job, update_job, get_job_by_id, delete_job_by_id, \
    delete_geopackage, create_gpkg_threaded, threads_available, bbox_size_allowed

jobs = Blueprint('jobs', __name__, url_prefix='/jobs')


@jobs.route('/', methods=['POST'])
def add_job():
    """Add new job.
    Add a new job and trigger the creation of a geopackage containing only
    the geometries that intersect the provided bounding box.
    ---
    parameters:
      - name: body
        in: body
        description: The bounding box
        schema:
          $ref: '#/definitions/PostBody'
        required: true
    responses:
      400:
        description: BBOX invalid, or BBOX area too big, or server busy.
        schema:
          type: object
          properties:
            success:
              type: boolean
            message:
              type: string
          example: {"success": false, "message": "Invalid BBOX"}
      201:
        description: The success response.
        schema:
          $ref: '#/definitions/PostResponse'
    definitions:
      PostResponse:
        type: object
        properties:
          success:
            type: boolean
            description: True, if the job was successfully created. False otherwise.
          job_id:
            type: integer
            description: The id of the created job.
        example: {"success": True, "job_id": 1}
      PostBody:
        type: object
        properties:
          bbox:
            type: array
            description: The Bounding Box in EPSG 4326 with [xMin, yMin, xMax, yMax].
            items:
              type: number
        example: {"bbox": [12.770159825707431, 53.38672734467538, 12.81314093379179, 53.40407138102892]}
    """
    post_body = request.json

    # bbox is always in 4326
    bbox = post_body.get('bbox')
    if bbox is None or not len(bbox) == 4:
        current_app.logger.info('Could not add job. Invalid BBOX.')
        return json.dumps({'success': False, 'message': Status.BBOX_INVALID.value}), 400, {'ContentType': 'application/json'}

    conn = db.pool.getconn()
    try:
        data_id = str(uuid.uuid4())

        if not bbox_size_allowed(conn, current_app, bbox):
            current_app.logger.info('Could not add job. BBOX size not allowed.')
            raise OrkaException(Status.BBOX_TOO_BIG.value)

        if not threads_available(conn, current_app):
            current_app.logger.info('Could not add job. No free threads available.')
            raise OrkaException(Status.NO_THREADS_AVAILABLE.value)

        job_id = create_job(conn, current_app, bbox, data_id)
        current_app.logger.debug(f'Added job with id {job_id}')
        update_job(job_id, conn, current_app, status=Status.RUNNING.value)

        current_app.logger.debug(f'Creating gpkg for job {job_id}')
        create_gpkg_threaded(current_app, request.base_url, job_id, data_id, bbox)
        response = json.dumps({'success': True, 'job_id': job_id}), 201, {'ContentType': 'application/json'}
    except OrkaException as e:
        response = json.dumps({'success': False, 'message': str(e)}), 400, {'ContentType': 'application/json'}
    except Exception as e:
        current_app.logger.info(f'Error adding job. {e}')
        response = json.dumps({'success': False}), 400, {'ContentType': 'application/json'}
    finally:
        db.pool.putconn(conn)

    return response


@jobs.route('/<int:job_id>', methods=['GET'])
def get_job(job_id):
    """Get the job.
    ---
    parameters:
      - name: job_id
        in: path
        description: The id of the job.
        type: integer
        required: true
    responses:
      200:
        description: The requested job.
        schema:
          $ref: '#/definitions/Job'
      404:
        description: Job not found.
    definitions:
      Job:
        description: The Job object.
        type: object
        properties:
          id:
            type: integer
            description: The id of the job
          minx:
            type: number
            description: The minX value of the provided Bounding Box.
          miny:
            type: number
            description: The minY value of the provided Bounding Box.
          maxx:
            type: number
            description: The maxX value of the provided Bounding Box.
          maxy:
            type: number
            description: The maxY value of the provided Bounding Box.
          status:
            $ref: '#/definitions/JobStatus'
      JobStatus:
        description: The status of a Job.
        type: string
        enum:
          - INIT
          - RUNNING
          - CREATED
          - ERROR
          - TIMEOUT
          - BBOX_TOO_BIG
          - BBOX_INVALID
          - NO_THREADS_AVAILABLE
    """
    conn = db.pool.getconn()
    try:
        job = get_job_by_id(job_id, conn, current_app)
        if job is None:
            current_app.logger.info(f'Could not get job {job_id}. Job not found.')
            raise OrkaException("Job not found.")
        if job['status'] != Status.CREATED.value:
            job.pop('data_id')
        response = job
    except OrkaException as e:
        response = '', 404
    except Exception as e:
        current_app.logger.info(f'Error getting job. {e}')
        response = '', 500
    finally:
        db.pool.putconn(conn)
    return response


@jobs.route('/<int:job_id>', methods=['PUT'])
def put_job(job_id):
    """Update a job.
    ---
    parameters:
      - name: job_id
        in: path
        description: The id of the job.
        type: integer
        required: true
      - name: body
        in: body
        description: The changed job.
        required: true
        schema:
          $ref: '#/definitions/Job'
    responses:
      201:
        description: Successfully updated.
        schema:
          $ref: '#/definitions/PutResponse'
      404:
        description: Job not found.
    definitions:
      PutResponse:
        type: object
        properties:
          success:
            type: boolean
            description: The success state of the request.
    """
    post_body = request.json
    conn = db.pool.getconn()
    try:
        job = get_job_by_id(job_id, conn, current_app)
        if job is None:
            current_app.logger.info(f'Could not update job {job_id}. Job not found.')
            raise OrkaException("Job not found.")
        update_job(job_id, conn, current_app, **post_body)
        db.pool.putconn(conn)
        response = json.dumps({'success': True}), 201, {'ContentType': 'application/json'}
    except OrkaException:
        response = json.dumps({'success': False}), 404, {'ContentType': 'application/json'}
    except Exception as e:
        current_app.logger.info(f'Error updating job. {e}')
        response = json.dumps({'success': False}), 500, {'ContentType': 'application/json'}
    finally:
        db.pool.putconn(conn)

    return response


@jobs.route('/<int:job_id>', methods=['DELETE'])
def delete_job(job_id):
    """Delete a job.
    Deletes a job and the corresponding geopackage file.
    ---
    parameters:
      - name: job_id
        in: path
        description: The id of the job.
        type: integer
        required: true
    responses:
      200:
        description: Successfully deleted.
        schema:
          $ref: '#/definitions/DeleteResponse'
      404:
        description: Job not found.
        schema:
          $ref: '#/definitions/DeleteResponse'
      400:
        description: Job could not be deleted.
        schema:
          $ref: '#/definitions/DeleteResponse'
    definitions:
      DeleteResponse:
        type: object
        properties:
          success:
            type: boolean
            description: True, if deleted successfully. False otherwise.
    """
    conn = db.pool.getconn()
    try:
        job = get_job_by_id(job_id, conn, current_app)
        if job is None:
            current_app.logger.info(f'Could not delete job {job_id}. Job not found.')
            raise OrkaException("Job not found")

        deleted_gpkg = delete_geopackage(job.get('data_id'), conn, current_app)
        if not deleted_gpkg:
            current_app.logger.info(f'Could not delete gpkg for job {job_id}')

        deleted = delete_job_by_id(job_id, conn, current_app)
        if not deleted:
            current_app.logger.info(f'Could not delete job with id {job_id}')
            raise OrkaException('Could not delete job.')

        current_app.logger.debug(f'Deleted job with id {job_id}')
        response = json.dumps({'success': True}), 200, {'ContentType': 'application/json'}
    except OrkaException as e:
        response = json.dumps({'success': False, 'message': str(e)}), 400, {'ContentType': 'application/json'}
    except Exception as e:
        current_app.logger.info(f'Error deleting job {e}')
        response = json.dumps({'success': False}), 500, {'ContentType': 'application/json'}
    finally:
        db.pool.putconn(conn)

    return response



from logging import Formatter
from logging.handlers import RotatingFileHandler


def setup_file_logger(**kwargs):
    file_handler = RotatingFileHandler(
        kwargs.get('logfile', 'orka.log'),
        maxBytes=1024
    )
    file_handler.setFormatter(Formatter(
        '[%(asctime)s] %(levelname)s in %(module)s: %(message)s'
    ))
    return file_handler



import os

from psycopg2.extras import RealDictCursor
from psycopg2.sql import SQL, Identifier, Composed, Placeholder

from orka_vector_api.enums import Status


def create_job(conn, app, bbox, data_id):
    schema = app.config['ORKA_DB_SCHEMA']
    if not _is_sane_schema(schema):
        raise Exception('Schema is not sane.')

    props = {
        'minx': float(bbox[0]),
        'miny': float(bbox[1]),
        'maxx': float(bbox[2]),
        'maxy': float(bbox[3]),
        'status': Status.INIT.value,
        'data_id': data_id
    }

    if False in [_is_sane(k, v) for k, v in props.items()]:
        raise Exception('Properties are not sane.')

    q = SQL('INSERT INTO {}.{} (minx, miny, maxx, maxy, status, data_id) '
            'VALUES (%(minx)s, %(miny)s, %(maxx)s, %(maxy)s, %(status)s, %(data_id)s) '
            'RETURNING id;').format(Identifier(schema), Identifier('jobs'))

    with conn.cursor() as cur:
        cur.execute(q, {'schema': schema, **props})
        job_id, = cur.fetchone()
        conn.commit()

    return job_id


def update_job(job_id, conn, app, **kwargs):
    schema = app.config['ORKA_DB_SCHEMA']
    if not _is_sane_schema(schema):
        raise Exception('Schema is not sane.')

    if False in [_is_sane(k, v) for k, v in kwargs.items() if k != 'id']:
        raise Exception("Attributes are not sane.")

    vals = [Composed([Identifier(k), SQL('='), Placeholder(k)]) for k in kwargs.keys() if k != 'id']
    q = SQL('UPDATE {schema}.{table} SET {data} WHERE id = %(job_id)s;').format(
        schema=Identifier(schema),
        table=Identifier('jobs'),
        data=SQL(',').join(vals)
    )

    if 'status' in kwargs.keys():
        status = kwargs.get('status')
        if status == Status.TIMEOUT.value or status == Status.ERROR.value:
            app.logger.info(f'Setting status to {status} for job with id {job_id}')

    with conn.cursor() as cur:
        cur.execute(q, {
            **kwargs,
            'job_id': job_id
        })
        conn.commit()


def get_job_by_id(job_id, conn, app):
    schema = app.config['ORKA_DB_SCHEMA']
    if not _is_sane_schema(schema):
        raise Exception('Schema is not sane.')

    cols = ['id', 'minx', 'miny', 'maxx', 'maxy', 'data_id', 'status']
    q = SQL('SELECT {cols} '
            'FROM {schema}.{table} '
            'WHERE id = %(job_id)s;').format(
        cols=SQL(',').join([Identifier(k) for k in cols]),
        schema=Identifier(schema),
        table=Identifier('jobs'))

    with conn.cursor(cursor_factory=RealDictCursor) as cur:
        cur.execute(q, {'job_id': job_id})
        job = cur.fetchone()

    return job


def get_job_id_by_dataid(data_id, conn, app):
    schema = app.config['ORKA_DB_SCHEMA']
    if not _is_sane_schema(schema):
        raise Exception('Schema is not sane.')

    q = SQL('SELECT id FROM {schema}.{table} WHERE data_id = %(data_id)s LIMIT 1;').format(
        schema=Identifier(schema),
        table=Identifier('jobs'))

    with conn.cursor() as cur:
        cur.execute(q, {'data_id': data_id})
        result = cur.fetchone()
        if result is None:
            job_id = None
        else:
            job_id = result[0]

    return job_id


def delete_job_by_id(job_id, conn, app):
    schema = app.config['ORKA_DB_SCHEMA']
    if not _is_sane_schema(schema):
        raise Exception('Schema is not sane.')

    q = SQL('DELETE FROM {schema}.{table} WHERE id = %(job_id)s;').format(
        schema=Identifier(schema),
        table=Identifier('jobs')
    )

    with conn.cursor() as cur:
        cur.execute(q, {'job_id': job_id})
        deleted_rows = cur.rowcount
        conn.commit()

    return deleted_rows == 1


def delete_geopackage(data_id, conn, app):
    gpkg_path = app.config['ORKA_GPKG_PATH']
    filename = data_id + '.gpkg'
    filepath = os.path.join(gpkg_path, filename)
    if os.path.exists(filepath):
        os.remove(filepath)
        return True
    else:
        return False


def count_running_jobs(conn, app):
    schema = app.config['ORKA_DB_SCHEMA']
    q = SQL('SELECT count(*) FROM {schema}.{table} WHERE status = %(status)s;').format(
        schema=Identifier(schema),
        table=Identifier('jobs')
    )

    with conn.cursor() as cur:
        cur.execute(q, {'status': Status.RUNNING.value})
        count = cur.fetchone()[0]
        conn.commit()

    return count


def threads_available(conn, app):
    max_threads = app.config['ORKA_MAX_THREADS']
    running_jobs = count_running_jobs(conn, app)
    # we have a watchdog for each thread, so we have to double it
    running_threads = running_jobs * 2
    free_threads = max_threads - running_threads
    return free_threads >= 2


def bbox_size_allowed(conn, app, bbox):
    minx = float(bbox[0])
    miny = float(bbox[1])
    maxx = float(bbox[2])
    maxy = float(bbox[3])

    max_area = app.config['ORKA_MAX_BBOX']
    q = 'SELECT ST_AREA(st_transform(geom, 3857))/1000000 from ST_MakeEnvelope(%(minx)s, %(miny)s, %(maxx)s, %(maxy)s, 4326) as geom;'
    with conn.cursor() as cur:
        cur.execute(q, {
            'minx': minx,
            'miny': miny,
            'maxx': maxx,
            'maxy': maxy
        })
        area = cur.fetchone()[0]
    return area <= max_area


def _is_sane(key, val):
    prop_map = {
        'minx': float,
        'miny': float,
        'maxx': float,
        'maxy': float,
        'status': str,
        'data_id': str
    }

    if not isinstance(key, str):
        return False
    if key not in prop_map:
        return False

    if val is None:
        return True
    if not isinstance(val, prop_map.get(key)):
        return False
    if prop_map.get(key) == str:
        if len(val) == 0:
            return False
        if '--' in val:
            return False

    return True


def _is_sane_schema(schema):
    if not isinstance(schema, str):
        return False
    if len(schema) == 0:
        return False
    if '--' in schema:
        return False
    if len(schema.split(' ')) != 1:
        return False

    return True



from psycopg2.pool import ThreadedConnectionPool
from flask import _app_ctx_stack, current_app


class OrkaDB(object):
    def _init_(self, app=None):
        self.app = app
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        app.config.setdefault('ORKA_DB_HOST', 'localhost')
        app.config.setdefault('ORKA_DB_PORT', 5432)
        app.config.setdefault('ORKA_DB_DATABASE', 'postgres')
        app.config.setdefault('ORKA_DB_MIN_CONNECTION', 1)
        app.config.setdefault('ORKA_DB_MAX_CONNECTION', 1)
        app.config.setdefault('ORKA_DB_SCHEMA', 'public')

        app.teardown_appcontext(self.teardown)

    def teardown(self, exception):
        pass

    def create_pool(self):
        return ThreadedConnectionPool(
            current_app.config['ORKA_DB_MIN_CONNECTION'],
            current_app.config['ORKA_DB_MAX_CONNECTION'],
            host=current_app.config['ORKA_DB_HOST'],
            port=current_app.config['ORKA_DB_PORT'],
            database=current_app.config['ORKA_DB_DATABASE'],
            user=current_app.config['ORKA_DB_USER'],
            password=current_app.config['ORKA_DB_PASSWORD']
        )

    @property
    def pool(self):
        ctx = _app_ctx_stack.top
        if ctx is not None:
            if not hasattr(ctx, 'orka_db_pool'):
                ctx.orka_db_pool = self.create_pool()
            return ctx.orka_db_pool




__version__ = '0.0.2'

import os

from flasgger import Swagger
from flask import Flask
from werkzeug.middleware.proxy_fix import ProxyFix

from orka_vector_api import logging_config
from orka_vector_api.logging_config import setup_file_logger
from orka_vector_api.orka_db import OrkaDB
from orka_vector_api.swagger_config import get_swagger_config

db = OrkaDB()
swagger = Swagger(template=get_swagger_config())


def create_app(test_config=None):
    app_kwargs = {
        'instance_relative_config': True
    }
    if os.environ.get('FLASK_ENV', '') != 'development':
        app_kwargs['instance_path'] = f'/var/{__name__}'

    # create and configure the app
    app = Flask(__name__, **app_kwargs)
    app.config.from_mapping(
        SECRET_KEY='dev'
    )

    if test_config is None:
        # load the instance config, if it exists, when not testing
        app.config.from_pyfile('config.py', silent=True)
    else:
        # load the test config if passed in
        app.config.from_mapping(test_config)

    # ensure the instance folder exists
    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass

    file_logger = setup_file_logger(logfile=app.config['ORKA_LOG_FILE'])
    app.logger.addHandler(file_logger)

    db.init_app(app)
    swagger.init_app(app)

    from orka_vector_api.views.status import status
    from orka_vector_api.views.jobs import jobs
    from orka_vector_api.views.data import data

    app.register_blueprint(status)
    app.register_blueprint(jobs)
    app.register_blueprint(data)

    if app.config['ENV'] == 'development':
        return app

    return ProxyFix(app, x_for=1, x_prefix=1)



import os
import subprocess
from os import listdir
from os.path import isfile, join, splitext
from threading import Event, Thread

from requests import put

from orka_vector_api.enums import Status


def _get_gpkg_cmd(filename, layername, sql, host=None, port=None, database=None, user=None, password=None):
    cmd = f'ogr2ogr -f "GPKG" {filename} ' \
          f'PG:"host={host} user={user} port={port} dbname={database} password={password}" ' \
          f'-sql "{sql}" ' \
          f'-nln "{layername}" ' \
          f'-t_srs EPSG:25833 ' \
          f'-append'

    return cmd


def _create_gpkg(data_id, bbox, timeout_e=None, error_e=None, db_props=None, gpkg_path='', layers_path=''):
    file_name = os.path.abspath(os.path.join(gpkg_path, data_id + '.gpkg'))
    layer_sqls = _get_layer_sqls(layers_path)
    for layer_name, layer_sql in layer_sqls.items():
        if timeout_e is not None and timeout_e.isSet():
            break
        gpkg_sql = _get_gpkg_sql(layer_sql, bbox)
        gpkg_sql_escaped = _escape_sql(gpkg_sql)
        print(gpkg_sql_escaped)
        cmd = _get_gpkg_cmd(file_name, layer_name, gpkg_sql_escaped, **db_props)
        proc = subprocess.run(cmd, shell=True, capture_output=True)
        # if proc.stderr:
        #     if error_e is not None:
        #         error_e.set()
        #     break
            # raise Exception(f'Error creating {file_name}: ' + proc.stderr.decode())
        if proc.returncode != 0:
            print(proc.stderr.decode())
            if error_e is not None:
                error_e.set()
            break
            # raise Exception(f'Error creating {file_name}: Program exited with non-zero code.')


def _escape_sql(sql):
    return sql.translate(str.maketrans({'"': r'\"'}))


def _get_layer_sqls(layers_path):
    layers = {}
    for fname in listdir(layers_path):
        fpath = join(layers_path, fname)
        if not isfile(fpath):
            continue
        if not fname.endswith('.sql'):
            continue

        lname, _ = splitext(fname)
        with open(fpath) as f:
            layers[lname] = ' '.join(f.read().splitlines())

    return layers


def _get_gpkg_sql(layer_sql, bbox):
    bbox_str = ', '.join([str(b) for b in bbox])
    # we use && (overlaps) instead of @> (contains), as we want to include all geometries that
    # in some way lie within the bbox
    # see https://www.postgresql.org/docs/9.1/functions-array.htm
    return (f'SELECT * FROM ({layer_sql}) AS l '
            f'WHERE l.geometry '
            f'&& ST_Transform(ST_MakeEnvelope({bbox_str}, 4326), ST_SRID(l.geometry))')


def create_gpkg_threaded(app, base_url, job_id, *args):
    db_props = {
        'host': app.config['PG_HOST'],
        'port': app.config['PG_PORT'],
        'database': app.config['PG_DATABASE'],
        'user': app.config['PG_USER'],
        'password': app.config['PG_PASSWORD']
    }
    gpkg_path = app.config['ORKA_GPKG_PATH']
    layers_path = app.config['ORKA_LAYERS_PATH']
    timeout = app.config['ORKA_THREAD_TIMEOUT']

    if not base_url.endswith('/'):
        base_url += '/'
    response_url = f'{base_url}{job_id}'

    layers_abs_path = os.path.abspath(layers_path)

    thread = Thread(target=_create_gpkg_threaded,
                    args=(response_url, *args,),
                    kwargs={
                        'timeout': timeout,
                        'db_props': db_props,
                        'gpkg_path': gpkg_path,
                        'layers_path': layers_abs_path
                    })
    thread.start()


def _create_gpkg_threaded(response_url, *args, timeout=None, **kwargs):
    timeout_e = Event()
    error_e = Event()
    thread = Thread(target=_create_gpkg, args=args, kwargs={'timeout_e': timeout_e, 'error_e': error_e, **kwargs})
    thread.start()

    killed = False
    if timeout is not None:
        thread.join(timeout)
        if thread.is_alive():
            killed = True
        timeout_e.set()
    thread.join()

    if error_e.isSet():
        return put(response_url, json={'status': Status.ERROR.value})
    if killed or error_e.isSet():
        return put(response_url, json={'status': Status.TIMEOUT.value})
    else:
        return put(response_url, json={'status': Status.CREATED.value})



import pathlib

from setuptools import setup, find_packages

README = (pathlib.Path(__file__).parent / 'README.md').read_text()

setup(
    name='orka_vector_api',
    version='0.0.2',
    description='Rest API for orka vector data',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/terrestris/OrKa-Vector-API',
    author='Jan Suleiman @ terrestris GmbH & Co. KG',
    author_email='info@terrestris.de',
    license='Apache-2.0',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'flask~=1.1.2',
        'psycopg2-binary~=2.8.6',
        'PyYAML~=5.4.1',
        'uuid~=1.30',
        'requests~=2.25.1',
        'flasgger~=0.9.5'
    ],
)



def get_swagger_config():
    return {
        "swagger": "2.0",
        "info": {
            "title": "OrKa Vector API",
            'description': 'The API documentation for the OrKa Vector API',
        },
        "schemes": [
            "http",
            "https"
        ]
    }
